==> kdepim-addons-17.08.0.tar.xz: kdepim-addons-17.08.0/kmail/editorplugins/insertspecialcharacter/insertspecialcharacterplugineditorinterface.h <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef INSERTSPECIALCHARACTERPLUGINEDITORINTERFACE_H
#define INSERTSPECIALCHARACTERPLUGINEDITORINTERFACE_H

#include <messagecomposer/plugineditorinterface.h>
#include <KPIMTextEdit/SelectSpecialCharDialog>
#include <QPointer>

class InsertSpecialCharacterPluginEditorInterface : public MessageComposer::PluginEditorInterface
{
    Q_OBJECT
public:
    explicit InsertSpecialCharacterPluginEditorInterface(QObject *parent = nullptr);
    ~InsertSpecialCharacterPluginEditorInterface();

    void createAction(KActionCollection *ac) override;
    void exec() override;

private Q_SLOTS:
    void slotActivated();
    void charSelected(QChar c);
private:
    QPointer<KPIMTextEdit::SelectSpecialCharDialog> mSelectSpecialChar;
};

#endif

==> kdepim-addons-20.04.0.tar.xz: kdepim-addons-20.04.0/kmail/editorplugins/insertspecialcharacter/insertspecialcharacterplugineditorinterface.h <==
/*
   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef INSERTSPECIALCHARACTERPLUGINEDITORINTERFACE_H
#define INSERTSPECIALCHARACTERPLUGINEDITORINTERFACE_H

#include <messagecomposer/plugineditorinterface.h>
#include <KPIMTextEdit/SelectSpecialCharDialog>
#include <QPointer>

class InsertSpecialCharacterPluginEditorInterface : public MessageComposer::PluginEditorInterface
{
    Q_OBJECT
public:
    explicit InsertSpecialCharacterPluginEditorInterface(QObject *parent = nullptr);
    ~InsertSpecialCharacterPluginEditorInterface() override;

    void createAction(KActionCollection *ac) override;
    void exec() override;

private:
    void charSelected(QChar c);
    void slotActivated();
    QPointer<KPIMTextEdit::SelectSpecialCharDialog> mSelectSpecialChar;
};

#endif
